@@ -211,9 +211,14 @@ func (p *dnsOverHTTPS) closeClient(client *http.Client) (err error) {
 func (p *dnsOverHTTPS) exchangeHTTPS(client *http.Client, req *dns.Msg) (resp *dns.Msg, err error) {
 	addr := p.Address()
 
-	logBegin(addr, req)
+	n := networkTCP
+	if isHTTP3(client) {
+		n = networkUDP
+	}
+
+	logBegin(addr, n, req)
 	resp, err = p.exchangeHTTPSClient(client, req)
-	logFinish(addr, err)
+	logFinish(addr, n, err)
 
 	return resp, err
 }
@@ -539,7 +544,7 @@ func (p *dnsOverHTTPS) createTransportH3(
 			tlsCfg *tls.Config,
 			cfg *quic.Config,
 		) (c quic.EarlyConnection, err error) {
-			c, err = quic.DialAddrEarlyContext(ctx, addr, tlsCfg, cfg)
+			c, err = quic.DialAddrEarly(ctx, addr, tlsCfg, cfg)
 			return c, err
 		},
 		DisableCompression: true,
@@ -630,7 +635,7 @@ func (p *dnsOverHTTPS) probeQUIC(addr string, tlsConfig *tls.Config, ch chan err
 	ctx, cancel := context.WithDeadline(context.Background(), time.Now().Add(timeout))
 	defer cancel()
 
-	conn, err := quic.DialAddrEarlyContext(ctx, addr, tlsConfig, p.getQUICConfig())
+	conn, err := quic.DialAddrEarly(ctx, addr, tlsConfig, p.getQUICConfig())
 	if err != nil {
 		ch <- fmt.Errorf("opening QUIC connection to %s: %w", p.addr, err)
 		return
